@@ -6,9 +6,13 @@ import os
 import sys
 from fnmatch import fnmatch
 import logging
+import re
+import copy
 
 import requests.sessions
+from requests.adapters import HTTPAdapter
 from requests.exceptions import HTTPError
+from requests import Response
 from jsonpatch import make_patch
 from clint.textui import progress
 import six
@@ -50,7 +54,7 @@ class Item(object):
     """
     # init()
     #_____________________________________________________________________________________
-    def __init__(self, identifier, metadata_timeout=None, config=None):
+    def __init__(self, identifier, metadata_timeout=None, config=None, max_retries=1):
         """
         :type identifier: str
         :param identifier: The globally unique Archive.org identifier
@@ -63,10 +67,16 @@ class Item(object):
         :type config: dict
         :param secure: (optional) Configuration options for session.
 
+        :type max_retries: int
+        :param max_retries: (optional) Maximum number of times to request
+                            a website if the connection drops. (default: 1)
+
         """
         self.session = session.ArchiveSession(config)
         self.protocol = 'https:' if self.session.secure else 'http:'
         self.http_session = requests.sessions.Session()
+        max_retries_adapter = HTTPAdapter(max_retries=max_retries)
+        self.http_session.mount('{0}//'.format(self.protocol), max_retries_adapter)
         self.http_session.cookies = self.session.cookies
         self.identifier = identifier
 
@@ -83,6 +93,7 @@ class Item(object):
         self.server = None
         self.uniq = None
         self.updated = None
+        self.tasks = None
 
         self._json = self.get_metadata(metadata_timeout)
         self.exists = False if self._json == {} else True
@@ -283,9 +294,29 @@ class Item(object):
 
         # Prepare patch to remove metadata elements with the value: "REMOVE_TAG".
         for key, val in metadata.items():
-            if val == 'REMOVE_TAG' or not val:
+            # Insert support for elements, i.e. subject[1] = 'value1'
+            contains_index = re.search(r'\[\d+\]', key)
+            if contains_index:
+                # Get the index
+                i = int(re.search(r'(?<=\[)\d+(?=\])', key).group())
+                # Create a new key, without the index, and delete the
+                # old key from dest.
+                _key = key.split('[')[0]
                 del dest[key]
-            if append:
+                # Copy the src value, and insert the new value.
+                _src = copy.deepcopy(src)
+                _val = _src.get(_key, [])
+                if not isinstance(_val, (list, set, tuple)):
+                    _val = [_val]
+                _val.insert(i, val)
+                # Update dest with the final value.
+                dest[_key] = _val
+            # Support for deleting elements.
+            elif val == 'REMOVE_TAG' or not val:
+                del dest[key]
+            # Support for appending strings to values (original value
+            # must be a string as well!).
+            elif append:
                 dest[key] = '{0} {1}'.format(src[key], val)
 
         json_patch = json.dumps(make_patch(src, dest).patch)
@@ -390,7 +421,7 @@ class Item(object):
         # Skip based on checksum.
         md5_sum = utils.get_md5(body)
         ia_file = self.get_file(key)
-        if (checksum) and (ia_file) and (ia_file.md5 == md5_sum):
+        if (checksum) and (not self.tasks) and (ia_file) and (ia_file.md5 == md5_sum):
             log.info('{f} already exists: {u}'.format(f=key, u=url))
             if verbose:
                 sys.stdout.write(' {f} already exists, skipping.\n'.format(f=key))
@@ -401,7 +432,9 @@ class Item(object):
                     'local copy'.format(i=self.identifier, f=key)
                 )
                 os.remove(body.name)
-            return
+            # Return an empty response object if checksums match.
+            # TODO: Is there a better way to handle this?
+            return Response()
 
         # require the Content-MD5 header when delete is True.
         if verify or delete:
